@@ -14,7 +14,7 @@ use WebService::Dropbox::Files::UploadSession;
 # use WebService::Dropbox::Sharing; comming soon...
 use WebService::Dropbox::Users;
 
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 __PACKAGE__->mk_accessors(qw/
     timeout
@@ -475,7 +475,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#oauth2-tok
 
 Disables the access token used to authenticate the call.
 
-    $dropbox->revoke;
+    my $result = $dropbox->revoke;
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#auth-token-revoke>
 
@@ -486,7 +486,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#auth-token
 Copy a file or folder to a different location in the user's Dropbox.
 If the source path is a folder all its contents will be copied.
 
-    $dropbox->copy($from_path, $to_path);
+    my $result = $dropbox->copy($from_path, $to_path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-copy>
 
@@ -494,7 +494,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-copy
 
 Get a copy reference to a file or folder. This reference string can be used to save that file or folder to another user's Dropbox by passing it to copy_reference/save.
 
-    $dropbox->copy_reference_get($path);
+    my $result = $dropbox->copy_reference_get($path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-copy_reference-get>
 
@@ -502,7 +502,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-copy
 
 Save a copy reference returned by copy_reference/get to the user's Dropbox.
 
-    $dropbox->copy_reference_save($copy_reference, $path);
+    my $result = $dropbox->copy_reference_save($copy_reference, $path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-copy_reference-save>
 
@@ -510,7 +510,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-copy
 
 Create a folder at a given path.
 
-    $dropbox->create_folder($path);
+    my $result = $dropbox->create_folder($path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-create_folder>
 
@@ -522,7 +522,7 @@ If the path is a folder, all its contents will be deleted too.
 
 A successful response indicates that the file or folder was deleted. The returned metadata will be the corresponding FileMetadata or FolderMetadata for the item at time of deletion, and not a DeletedMetadata object.
 
-    $dropbox->delete($path);
+    my $result = $dropbox->delete($path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-delete>
 
@@ -566,9 +566,9 @@ Returns the metadata for a file or folder.
 
 Note: Metadata for the root folder is unsupported.
 
-    $dropbox->get_metadata($path);
+    my $result = $dropbox->get_metadata($path);
 
-    $dropbox->get_metadata($path, {
+    my $result = $dropbox->get_metadata($path, {
         include_media_info => JSON::true,
         include_deleted => JSON::true,
         include_has_explicit_shared_members => JSON::false,
@@ -614,7 +614,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-get_
 
 Get a temporary link to stream content of a file. This link will expire in four hours and afterwards you will get 410 Gone. Content-Type of the link is determined automatically by the file's mime type.
 
-    $dropbox->get_temporary_link($path);
+    my $result = $dropbox->get_temporary_link($path);
 
     my $content_type = $dropbox->res->header('Content-Type');
 
@@ -667,9 +667,9 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-get_
 
 Returns the contents of a folder.
 
-    $dropbox->list_folder($path);
+    my $result = $dropbox->list_folder($path);
 
-    $dropbox->list_folder($path, {
+    my $result = $dropbox->list_folder($path, {
         recursive => JSON::false,
         include_media_info => JSON::false,
         include_deleted => JSON::false,
@@ -682,7 +682,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-list
 
 Once a cursor has been retrieved from list_folder, use this to paginate through all files and retrieve updates to the folder.
 
-    $dropbox->list_folder_continue($cursor);
+    my $result = $dropbox->list_folder_continue($cursor);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-list_folder-continue>
 
@@ -690,9 +690,9 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-list
 
 A way to quickly get a cursor for the folder's state. Unlike list_folder, list_folder/get_latest_cursor doesn't return any entries. This endpoint is for app which only needs to know about new files and modifications and doesn't need to know about files that already exist in Dropbox.
 
-    $dropbox->list_folder_get_latest_cursor($path);
+    my $result = $dropbox->list_folder_get_latest_cursor($path);
 
-    $dropbox->list_folder_get_latest_cursor($path, {
+    my $result = $dropbox->list_folder_get_latest_cursor($path, {
         recursive => JSON::false,
         include_media_info => JSON::false,
         include_deleted => JSON::false,
@@ -705,9 +705,9 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-list
 
 A longpoll endpoint to wait for changes on an account. In conjunction with list_folder/continue, this call gives you a low-latency way to monitor an account for file changes. The connection will block until there are changes available or a timeout occurs. This endpoint is useful mostly for client-side apps. If you're looking for server-side notifications, check out our webhooks documentation.
 
-    $dropbox->list_folder_longpoll($cursor);
+    my $result = $dropbox->list_folder_longpoll($cursor);
 
-    $dropbox->list_folder_longpoll($cursor, {
+    my $result = $dropbox->list_folder_longpoll($cursor, {
         timeout => 30
     });
 
@@ -717,9 +717,9 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-list
 
 Return revisions of a file.
 
-    $dropbox->list_revisions($path);
+    my $result = $dropbox->list_revisions($path);
 
-    $dropbox->list_revisions($path, {
+    my $result = $dropbox->list_revisions($path, {
         limit => 10
     });
 
@@ -729,7 +729,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-list
 
 Return revisions of a file.
 
-    $dropbox->move($from_path, $to_path);
+    my $result = $dropbox->move($from_path, $to_path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-move>
 
@@ -739,7 +739,7 @@ Permanently delete the file or folder at a given path (see https://www.dropbox.c
 
 Note: This endpoint is only available for Dropbox Business apps.
 
-    $dropbox->permanently_delete($path);
+    my $result = $dropbox->permanently_delete($path);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-permanently_delete>
 
@@ -747,7 +747,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-perm
 
 Restore a file to a specific revision.
 
-    $dropbox->restore($path, $rev);
+    my $result = $dropbox->restore($path, $rev);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-restore>
 
@@ -755,7 +755,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-rest
 
 Save a specified URL into a file in user's Dropbox. If the given path already exists, the file will be renamed to avoid the conflict (e.g. myfile (1).txt).
 
-    $dropbox->save_url($path, $url);
+    my $result = $dropbox->save_url($path, $url);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-save_url>
 
@@ -763,7 +763,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-save
 
 Check the status of a save_url job.
 
-    $dropbox->save_url_check_job_status($async_job_id);
+    my $result = $dropbox->save_url_check_job_status($async_job_id);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#files-save_url-check_job_status>
 
@@ -773,9 +773,9 @@ Searches for files and folders.
 
 Note: Recent changes may not immediately be reflected in search results due to a short delay in indexing.
 
-    $dropbox->search($path);
+    my $result = $dropbox->search($path);
 
-    $dropbox->search($path, {
+    my $result = $dropbox->search($path, {
         query => 'prime numbers',
         start => 0,
         max_results => 100,
@@ -793,9 +793,9 @@ Do not use this to upload a file larger than 150 MB. Instead, create an upload s
     # File Handle
     my $content = IO::File->new('./my.cnf', '<');
 
-    $dropbox->upload($path, $content);
+    my $result = $dropbox->upload($path, $content);
 
-    $dropbox->upload($path, $content, {
+    my $result = $dropbox->upload($path, $content, {
         mode => 'add',
         autorename => JSON::true,
         mute => JSON::false
@@ -810,9 +810,9 @@ Uploads large files by upload_session API
     # File Handle
     my $content = IO::File->new('./mysql.dump', '<');
 
-    $dropbox->upload($path, $content);
+    my $result = $dropbox->upload($path, $content);
 
-    $dropbox->upload($path, $content, {
+    my $result = $dropbox->upload($path, $content, {
         mode => 'add',
         autorename => JSON::true,
         mute => JSON::false
@@ -856,7 +856,7 @@ A single request should not upload more than 150 MB of file contents.
     # File Handle
     my $content = IO::File->new('./access.log.1', '<');
 
-    $dropbox->upload_session_append_v2($content, {
+    my $result = $dropbox->upload_session_append_v2($content, {
         cursor => {
             session_id => $session_id,
             offset => $offset
@@ -875,7 +875,7 @@ A single request should not upload more than 150 MB of file contents.
     # File Handle
     my $content = IO::File->new('./access.log.last', '<');
 
-    $dropbox->upload_session_finish($content, {
+    my $result = $dropbox->upload_session_finish($content, {
         cursor => {
             session_id => $session_id,
             offset => $offset
@@ -896,7 +896,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#files-uplo
 
 Get information about a user's account.
 
-    $dropbox->get_account($account_id);
+    my $result = $dropbox->get_account($account_id);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_account>
 
@@ -904,7 +904,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_
 
 Get information about multiple user accounts. At most 300 accounts may be queried per request.
 
-    $dropbox->get_account_batch($account_id);
+    my $result = $dropbox->get_account_batch($account_id);
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_account_batch>
 
@@ -912,7 +912,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_
 
 Get information about the current user's account.
 
-    $dropbox->get_current_account;
+    my $result = $dropbox->get_current_account;
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_current_account>
 
@@ -920,7 +920,7 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_
 
 Get the space usage information for the current user's account.
 
-    $dropbox->get_space_usage;
+    my $result = $dropbox->get_space_usage;
 
 L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_space_usage>
 
@@ -928,14 +928,21 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_
 
 =head3 error : str
 
-    warn $dropbox->error;
+    my $result = $dropbox->$some_api;
+    unless ($result) {
+        die $dropbox->error;
+    }
 
 =head3 req : HTTP::Request or Furl::Request
 
+    my $result = $dropbox->$some_api;
+
     warn $dropbox->req->as_string;
 
 =head3 res : HTTP::Response or Furl::Response
 
+    my $result = $dropbox->$some_api;
+
     warn $dropbox->res->code;
     warn $dropbox->res->header('ETag');
     warn $dropbox->res->header('Content-Type');
@@ -947,12 +954,16 @@ L<https://www.dropbox.com/developers/documentation/http/documentation#users-get_
 
 enable HTTP_PROXY, NO_PROXY
 
+    my $dropbox = WebService::Dropbox->new();
+
     $dropbox->env_proxy;
 
 =head3 debug
 
 enable or disable debug mode
 
+    my $dropbox = WebService::Dropbox->new();
+
     $dropbox->debug; # disabled
     $dropbox->debug(0); # disabled
     $dropbox->debug(1); # enabled
@@ -961,6 +972,8 @@ enable or disable debug mode
 
 more warnings.
 
+    my $dropbox = WebService::Dropbox->new();
+
     $dropbox->verbose; # disabled
     $dropbox->verbose(0); # disabled
     $dropbox->verbose(1); # enabled
